@@ -11,7 +11,9 @@ sub initialize {
 }
 
 sub failing_test : Test {
-  fail "but this is to be skipped";
+  my $class = shift;
+
+  fail $class->message("but this is to be skipped");
 }
 
 1;
